OiRA

# OiRA@Daimler

Online Interactive Risk Assessment

## My risk assessments

Filters

Close

Hide archived risk assessments

Select an earlier risk assessment to complete or review or start a new session.

- #### Private Security, Grafton Street

  Started 5 May 2019

  More

- #### Commercial guarding, Leicester

  Started 6 March 2020

  More

## Available OiRA tools

EU Cleaning EU Hairdressing EU Live Performance - Productions Leather and Tanning Maritime Transport Private Security

Back

## index-logged-in.html

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More